==> 0.11.3.tar.gz: lib/src/router/common/standard_routes_impl.dart <==
library ac_dart.addon_routebuilder.standard.impl;

import 'package:atlassian_connect_shelf/router.dart' hide router;

import 'package:logging/logging.dart';
import 'package:atlassian_connect_shelf/src/router/common/standard_routes.dart';
import 'package:atlassian_connect_shelf/src/router/common/common_routes_impl.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/standard.dart';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:shelf_auth/shelf_auth.dart';
import 'package:shelf_oauth/shelf_oauth.dart';
import 'package:mojito/mojito.dart' hide Router, router;

final Logger _log = new Logger('ac_dart.addon_routebuilder.standard');

abstract class StandardAddonRouterBuilderImpl<
        M extends ModuleList,
        S extends Scope,
        A extends ConnectAddon<M, S>,
        B extends StandardDescriptorBuilder<M, S, A>>
    extends CommonAddonRouterBuilderImpl<B, S>
    implements StandardAddonRouterBuilder<S> {
  StandardAddonRouterBuilderImpl(
      Router router,
      path,
      B descriptorBuilder,
      String addonKey,
      Uri baseUrl,
      AcHostRegistrationRepository hostRegistrationRepository,
      IsDevMode isDevMode,
      {SessionHandler sessionHandler,
      String addonSecret,
      ClientIdFactory oauthClientIdFactory})
      : super(router, path, descriptorBuilder, addonKey, baseUrl,
            hostRegistrationRepository, isDevMode,
            oauthClientIdFactory: oauthClientIdFactory,
            sessionHandler: sessionHandler,
            addonSecret: addonSecret);

  @override
  void addWebhook(path, String event, String name, Function handler,
      {Map<String, Object> params: const {}}) {
    router.post(path, handler, name: name);
    descriptorBuilder.addWebhook(event, name, params);
  }

  void addSpaPage(
      String moduleType, path, String key, String name, ModuleLocation location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    final _spaBasePath = spaBasePath != null ? spaBasePath : 'ui';

    descriptorBuilder.addPage(moduleType, key, name, location);

    addSpaRedirect(path, name,
        spaBasePath: _spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragmentParams: additionalUriFragment);
  }

  void addSpaAdminPage(path, String key, String name, ModuleLocation location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    addSpaPage(CoreModuleTypes.adminPage, path, key, name, location,
        spaBasePath: spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragment: additionalUriFragment);
  }

  void addSpaGeneralPage(path, String key, String name, ModuleLocation location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    addSpaPage(CoreModuleTypes.generalPage, path, key, name, location,
        spaBasePath: spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragment: additionalUriFragment);
  }
}

==> 0.11.6.tar.gz: lib/src/router/common/standard_routes_impl.dart <==
library ac_dart.addon_routebuilder.standard.impl;

import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:atlassian_connect_shelf/router.dart' hide router;
import 'package:atlassian_connect_shelf/src/descriptor_builders/standard.dart';
import 'package:atlassian_connect_shelf/src/router/common/common_routes_impl.dart';
import 'package:atlassian_connect_shelf/src/router/common/standard_routes.dart';
import 'package:logging/logging.dart';
import 'package:mojito/mojito.dart' hide Router, router;
import 'package:shelf_auth/shelf_auth.dart';
import 'package:shelf_oauth/shelf_oauth.dart';

final Logger _log = new Logger('ac_dart.addon_routebuilder.standard');

abstract class StandardAddonRouterBuilderImpl<
        M extends ModuleList,
        S extends Scope,
        A extends ConnectAddon<M, S>,
        B extends StandardDescriptorBuilder<M, S, A>,
        L extends ModuleLocation> extends CommonAddonRouterBuilderImpl<B, S>
    implements StandardAddonRouterBuilder<S, L> {
  StandardAddonRouterBuilderImpl(
      Router router,
      path,
      B descriptorBuilder,
      String addonKey,
      Uri baseUrl,
      AcHostRegistrationRepository hostRegistrationRepository,
      IsDevMode isDevMode,
      {SessionHandler sessionHandler,
      String addonSecret,
      ClientIdFactory oauthClientIdFactory})
      : super(router, path, descriptorBuilder, addonKey, baseUrl,
            hostRegistrationRepository, isDevMode,
            oauthClientIdFactory: oauthClientIdFactory,
            sessionHandler: sessionHandler,
            addonSecret: addonSecret);

  @override
  void addWebhook(path, String event, String name, Function handler,
      {Map<String, Object> params: const {}}) {
    router.post(path, handler, name: name);
    descriptorBuilder.addWebhook(event, name, params);
  }

  void addSpaPage(String moduleType, path, String key, String name, L location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    final _spaBasePath = spaBasePath != null ? spaBasePath : 'ui';

    descriptorBuilder.addPage(moduleType, key, name, location);

    addSpaRedirect(path, name,
        spaBasePath: _spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragmentParams: additionalUriFragment);
  }

  void addPage(String moduleType, path, String key, String name, L location,
      Function handler) {
    descriptorBuilder.addPage(moduleType, key, name, location);

    get(path, name, handler);
  }

  void addSpaAdminPage(path, String key, String name, L location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    addSpaPage(CoreModuleTypes.adminPage, path, key, name, location,
        spaBasePath: spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragment: additionalUriFragment);
  }

  void addSpaGeneralPage(path, String key, String name, L location,
      {String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    addSpaPage(CoreModuleTypes.generalPage, path, key, name, location,
        spaBasePath: spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragment: additionalUriFragment);
  }
}
